from setuptools import setup

setup(name='py_distrib',
      version='0.1',
      description='Gaussian distributions',
      packages=['py_distrib'],
      author = "Kavii Suri",
      author_email="surikavii@gmail.com",
      zip_safe=False)
